@@ -1,7 +1,8 @@
 from django.db import models
 from django.contrib.admin import widgets as admin_widgets
-from djangocms_text_ckeditor.html import clean_html
-from djangocms_text_ckeditor.widgets import TextEditorWidget
+from .html import clean_html
+from .widgets import TextEditorWidget
+
 try:
     from south.modelsinspector import add_introspection_rules
     add_introspection_rules([], ['^djangocms_text_ckeditor\.fields\.HTMLField'])
